@@ -1,4 +1,4 @@
-__version__ = '1.15.0'
+__version__ = '1.16.0'
 Version = __version__  # for backward compatibility
 __all__ = ["PopbillException", "JoinForm", "ContactInfo", "CorpInfo",
            "TaxinvoiceService", "Taxinvoice", "TaxinvoiceDetail", "Contact",
@@ -9,7 +9,7 @@ __all__ = ["PopbillException", "JoinForm", "ContactInfo", "CorpInfo",
            "HTTaxinvoiceService", "HTCashbillService",
            "ClosedownService",
            "KakaoService", "KakaoReceiver", "KakaoButton",
-           "EasyFinBankService"]
+           "EasyFinBankService", "BankAccountInfo"]
 
 from .base import PopbillException, JoinForm, ContactInfo, CorpInfo
 from .taxinvoiceService import *
